import { Fdc3SystemChannelListener } from './fdc3-system-channel-listener';
/**
 * fdc3-context-listener
 * Util element to listen to the context on a fdc3 app channel
 * @public
 * @tagname fdc3-context-listener
 * @example
 * ```ts
 * import { customElement, GenesisElement, html } from '@genesislcap/web-core';
 * @customElement({
 *   name: 'example-component',
 *   template: html<ExampleComponent>`
 *    <fdc3-context-listener
 *      @channel-event="${(x, ctx) => x.handleChannelMessage(customEvent(ctx))}"
 *      context-type="fdc3.position"
 *      channel-name="my_custom_channel">
 *    </fdc3-context-listener>
 *   `,
 * })
 * class ExampleComponent extends GenesisElement {
 *   handleChannelMessage(e: CustomEvent) {
 *     const message = e.detail;
 *     if (message?.id?.ticker) {
 *       console.log(message.id.ticker);
 *       // ToDo: handle the message as you like
 *     }
 *   }
 * }
 * ```
 * @param Context - the fdc3 context type
 * @fires channel-event - Dispatched when an event matching the context is dispatched from the system channel
 */
export declare class Fdc3ContextListener extends Fdc3SystemChannelListener {
    /**
     * The name of the channel you want to listen to. Read more about fdc3 app channels at https://fdc3.finos.org/docs/api/spec#app-channels
     * @example this will listen to the system channel for updates on the type `my_custom_channel` with context `fdc3.position`
     * ```ts
     *  <fdc3-context-listener context-type="fdc3.position" channel-name="my_custom_channel"></fdc3-context-listener>
     * ```
     */
    channelName: string;
    protected addChannelListener(): Promise<void>;
}
//# sourceMappingURL=fdc3-context-listener.d.ts.map